==> qgis-3.0.0.tar.bz2: qgis-3.0.0/python/plugins/processing/algs/grass7/ext/i_colors_enhance.py <==
# -*- coding: utf-8 -*-

"""
***************************************************************************
    i_colors_enhance.py
    -------------------
    Date                 : March 2016
    Copyright            : (C) 2016 by Médéric Ribreux
    Email                : medspx at medspx dot fr
***************************************************************************
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
***************************************************************************
"""

__author__ = 'Médéric Ribreux'
__date__ = 'March 2016'
__copyright__ = '(C) 2016, Médéric Ribreux'

# This will get replaced with a git SHA1 when you do a git archive

__revision__ = '49858ca4978819f604fa70b9ad09541dbf493ec9'

from .i import exportInputRasters


def processCommand(alg, parameters, context):
    # Temporary remove outputs:
    alg.processCommand(parameters, context, True)


def processOutputs(alg, parameters, context):
    # Input rasters are output rasters
    rasterDic = {'red': 'redoutput', 'green': 'greenoutput', 'blue': 'blueoutput'}
    exportInputRasters(alg, parameters, context, rasterDic)

==> qgis-3.2.3.tar.bz2: qgis-3.2.3/python/plugins/processing/algs/grass7/ext/i_colors_enhance.py <==
# -*- coding: utf-8 -*-

"""
***************************************************************************
    i_colors_enhance.py
    -------------------
    Date                 : March 2016
    Copyright            : (C) 2016 by Médéric Ribreux
    Email                : medspx at medspx dot fr
***************************************************************************
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
***************************************************************************
"""

__author__ = 'Médéric Ribreux'
__date__ = 'March 2016'
__copyright__ = '(C) 2016, Médéric Ribreux'

# This will get replaced with a git SHA1 when you do a git archive

__revision__ = '9b176802e5512bc310765d8ebe4e44b5f4663453'

from .i import exportInputRasters


def processCommand(alg, parameters, context, feedback):
    # Temporary remove outputs:
    alg.processCommand(parameters, context, feedback, True)


def processOutputs(alg, parameters, context, feedback):
    # Input rasters are output rasters
    rasterDic = {'red': 'redoutput', 'green': 'greenoutput', 'blue': 'blueoutput'}
    exportInputRasters(alg, parameters, context, rasterDic)
